StoreWriter

Struct StoreWriter 

pub struct StoreWriter { /* private fields */ }
Appends events, prompts and ingest cursors to the store.

Implementations

Source

impl StoreWriter

pub fn open(paths: StorePaths) -> Result<Self>

Open the store at paths, creating ~/.warden/ and its subdirectories 0700 if missing.

pub fn paths(&self) -> &StorePaths

pub fn append_event(&mut self, event: &Event) -> Result<Partition>

Append one event to events/YYYY-MM.jsonl, chosen by its UTC month.

pub fn append_prompt( &mut self, ts_ms: i64, prompt: &PromptRecord, ) -> Result<Partition>

Append prompt text to the partition matching its event’s timestamp.

pub fn append_cursor(&mut self, cursor: &IngestCursor) -> Result<()>

Append an ingest cursor to state/ingest.jsonl.